@@ -192,12 +192,12 @@
         <translation>Използване на персонализирана команда за заключване на екрана</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Избиране на мениджър на прозорци</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation>Избиране на програма за заключване на екрана</translation>
     </message>
@@ -262,7 +262,7 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
+        <source>Wayland Settings</source>
         <translation>Настройки на Wayland</translation>
     </message>
     <message>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>Композитор на Wayland:</translation>
+        <source>Wayland compositor</source>
+        <translation>Композитор на Wayland</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,7 +407,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
+        <source>Screenlock command</source>
         <translation>Команда за заключване на екрана:</translation>
     </message>
     <message>
