@@ -192,12 +192,12 @@
         <translation>Usa una ordre de blocatge de pantalla personalitzada</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Seleccioneu un gestor de finestres</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation>Seleccioneu un blocador de pantalla</translation>
     </message>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Configuració de Wayland (experimental)</translation>
+        <source>Wayland Settings</source>
+        <translation>Configuració de Wayland</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>Compositor Wayland:</translation>
+        <source>Wayland compositor</source>
+        <translation>Compositor Wayland</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,7 +407,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
+        <source>Screenlock command</source>
         <translation>Ordre de blocatge de la pantalla:</translation>
     </message>
     <message>
