@@ -104,7 +104,7 @@
         <location filename="../autostartpage.cpp" line="145"/>
         <location filename="../autostartpage.cpp" line="180"/>
         <source>Name should not start with dot or contain slash</source>
-        <translation type="unfinished"></translation>
+        <translation>Der Name sollte nicht mit einem Punkt beginnen oder einen Schrägstrich enthalten</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="156"/>
@@ -182,14 +182,14 @@
         <translation>Benutzerdefinierten Befehl zur Bildschirmsperre verwenden</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Fensterverwaltung auswählen</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
-        <translation type="unfinished"></translation>
+        <translation>Bildschirmsperre auswählen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="152"/>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Wayland-Einstellungen (experimentell)</translation>
+        <source>Wayland Settings</source>
+        <translation>Wayland-Einstellungen</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -397,7 +397,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
+        <source>Wayland compositor</source>
         <translation>Wayland-Compositor:</translation>
     </message>
     <message>
@@ -408,7 +408,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
+        <source>Screenlock command</source>
         <translation>Befehl für Bildschirm sperren:</translation>
     </message>
     <message>
