@@ -104,7 +104,7 @@
         <location filename="../autostartpage.cpp" line="145"/>
         <location filename="../autostartpage.cpp" line="180"/>
         <source>Name should not start with dot or contain slash</source>
-        <translation type="unfinished"></translation>
+        <translation>Le nom ne doit pas commencer par un point ni contenir de barre oblique (/)</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="156"/>
@@ -174,7 +174,7 @@
     <message>
         <location filename="../basicsettings.ui" line="201"/>
         <source>Use custom screen lock command</source>
-        <translation type="unfinished"></translation>
+        <translation>Utiliser le bouton de verrouillage d&apos;écran personnalisé</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
@@ -192,14 +192,14 @@
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Sélectionner un gestionnaire de fenêtres</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélectionner un verrouillage d&apos;écran</translation>
     </message>
 </context>
 <context>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Paramètres Waylant (Expérimental)</translation>
+        <source>Wayland Settings</source>
+        <translation>Paramètres Wayland</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>Compositeur Wayland&#xa0;:</translation>
+        <source>Wayland compositor</source>
+        <translation>Compositeur Wayland</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,8 +407,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
-        <translation>Commande de verrouillage de l&apos;écran&#xa0;:</translation>
+        <source>Screenlock command</source>
+        <translation>Commande de verrouillage de l&apos;écran</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="71"/>
