@@ -192,12 +192,12 @@
         <translation>להשתמש בפקודת נעילת מסך משלך</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>בחירת מנהל חלונות</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation>בחירת נועל מסך</translation>
     </message>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>הגדרות Wayland (ניסיוניות)</translation>
+        <source>Wayland Settings</source>
+        <translation>הגדרות Wayland</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>מנהל חלונאי ל־Wayland:</translation>
+        <source>Wayland compositor</source>
+        <translation>מנהל חלונאי ל־Wayland</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,8 +407,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
-        <translation>פעולת נעילת מסך:</translation>
+        <source>Screenlock command</source>
+        <translation>פקודת נעילת מסך</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="71"/>
