@@ -59,7 +59,7 @@
     <message>
         <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
-        <translation>Zaobilaženje: %1</translation>
+        <translation>Nadjačavanja: %1</translation>
     </message>
 </context>
 <context>
@@ -104,7 +104,7 @@
         <location filename="../autostartpage.cpp" line="145"/>
         <location filename="../autostartpage.cpp" line="180"/>
         <source>Name should not start with dot or contain slash</source>
-        <translation type="unfinished"></translation>
+        <translation>Ime ne smije započeti točkom ili sadržati kosu crtu</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="156"/>
@@ -149,7 +149,7 @@
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pod Waylandom prilagodi skaliranje putem postavki kompozitora ili kanshija.</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="114"/>
@@ -189,17 +189,17 @@
     <message>
         <location filename="../basicsettings.ui" line="201"/>
         <source>Use custom screen lock command</source>
-        <translation type="unfinished"></translation>
+        <translation>Koristi prilagođenu naredbu za zaključavanje ekrana</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Odaberi upravljač prozora</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
-        <translation type="unfinished"></translation>
+        <translation>Odaberi zaključavanje ekrana</translation>
     </message>
 </context>
 <context>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Wayland postavke (eksperimentalno)</translation>
+        <source>Wayland Settings</source>
+        <translation>Wayland postavke</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation type="unfinished"></translation>
+        <source>Wayland compositor</source>
+        <translation>Wayland kompozitor:</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,7 +407,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
+        <source>Screenlock command</source>
         <translation>Naredba za zaključavanje ekrana:</translation>
     </message>
     <message>
@@ -418,7 +418,7 @@
     <message>
         <location filename="../waylandsettings.cpp" line="98"/>
         <source>Select a Wayland Compositor</source>
-        <translation type="unfinished"></translation>
+        <translation>Odaberi Wayland kompozitor</translation>
     </message>
     <message>
         <location filename="../waylandsettings.cpp" line="103"/>
