@@ -192,12 +192,12 @@
         <translation>Ferma</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>Seleziona un gestore delle finestre</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation>Seleziona un blocco schermo</translation>
     </message>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Impostazioni Wayland (sperimentale)</translation>
+        <source>Wayland Settings</source>
+        <translation>Impostazioni Wayland</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>Compositore Wayland:</translation>
+        <source>Wayland compositor</source>
+        <translation>Compositore Wayland</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,8 +407,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
-        <translation>Comando per bloccare lo schermo:</translation>
+        <source>Screenlock command</source>
+        <translation>Comando per bloccare lo schermo</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="71"/>
