@@ -192,12 +192,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>ਵਿੰਡੋ ਮੈਨੇਜਰ ਚੁਣੋ</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation type="unfinished"></translation>
     </message>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>ਵੇਅਲੈਂਡ ਸੈਟਿੰਗਾਂ (ਤਜਰਬੇ ਅਧੀਨ)</translation>
+        <source>Wayland Settings</source>
+        <translation>ਵੇਅਲੈਂਡ ਸੈਟਿੰਗਾਂ</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,7 +396,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
+        <source>Wayland compositor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -407,7 +407,7 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
+        <source>Screenlock command</source>
         <translation>ਸਕਰੀਨ ਲਾਕ ਕਰਨ ਵਾਲੀ ਕਮਾਂਡ:</translation>
     </message>
     <message>
