@@ -192,12 +192,12 @@
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="197"/>
+        <location filename="../basicsettings.cpp" line="200"/>
         <source>Select a window manager</source>
         <translation>選擇一個視窗管理員</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="212"/>
+        <location filename="../basicsettings.cpp" line="215"/>
         <source>Select a screenlocker</source>
         <translation>選擇螢幕鎖定器</translation>
     </message>
@@ -262,8 +262,8 @@
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="67"/>
-        <source>Wayland Settings (Experimental)</source>
-        <translation>Wayland 設定(實驗性)</translation>
+        <source>Wayland Settings</source>
+        <translation>Wayland 設定</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="74"/>
@@ -396,8 +396,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="30"/>
-        <source>Wayland compositor:</source>
-        <translation>Wayland 合成器：</translation>
+        <source>Wayland compositor</source>
+        <translation>Wayland 合成器</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="49"/>
@@ -407,8 +407,8 @@
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="59"/>
-        <source>Screenlock command:</source>
-        <translation>螢幕鎖定指令：</translation>
+        <source>Screenlock command</source>
+        <translation>螢幕鎖定指令</translation>
     </message>
     <message>
         <location filename="../waylandsettings.ui" line="71"/>
