@@ -106,7 +106,8 @@ void LXQtModuleManager::startAutostartApps()
     bool isWayland((QGuiApplication::platformName() == QLatin1String("wayland")));
     for (XdgDesktopFileList::const_iterator i = fileList.constBegin(); i != fileList.constEnd(); ++i)
     {
-        if (isWayland && i->value(QSL("X-LXQt-X11-Only"), false).toBool())
+        if (i->value(QSL("X-LXQt-Autostart-disabled"), false).toBool()
+            || (isWayland && i->value(QSL("X-LXQt-X11-Only"), false).toBool()))
         {
             continue;
         }
@@ -287,6 +288,22 @@ void LXQtModuleManager::stopProcess(const QString& name)
         mNameMap[name]->terminate();
 }
 
+void LXQtModuleManager::execDesktopFile(const QString& name)
+{
+    XdgDesktopFile xdg;
+    if (!xdg.load(name))
+    {
+        qCWarning(SESSION) << "Desktop file" << name << "is not valid";
+        return;
+    }
+    if (!xdg.isSuitable())
+    {
+        qCWarning(SESSION) << "Desktop file" << name << "is not applicable";
+        return;
+    }
+    xdg.startDetached();
+}
+
 QStringList LXQtModuleManager::listModules() const
 {
     return QStringList(mNameMap.keys());
