@@ -35,12 +35,12 @@
     <message>
         <location filename="../src/sessionapplication.cpp" line="89"/>
         <source>DBus Environment</source>
-        <translation type="unfinished"></translation>
+        <translation>DBus prostředí</translation>
     </message>
     <message>
         <location filename="../src/sessionapplication.cpp" line="90"/>
         <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
-        <translation type="unfinished"></translation>
+        <translation>Prostředí DBus aktivace nebylo zaktualizováno. Může se stát, že některé aplikace nebudou správně fungovat</translation>
     </message>
 </context>
 <context>
