@@ -4,12 +4,12 @@
 <context>
     <name>LXQtModuleManager</name>
     <message>
-        <location filename="../src/lxqtmodman.cpp" line="323"/>
+        <location filename="../src/lxqtmodman.cpp" line="347"/>
         <source>Crash Report</source>
         <translation>Kræsjrapport</translation>
     </message>
     <message>
-        <location filename="../src/lxqtmodman.cpp" line="324"/>
+        <location filename="../src/lxqtmodman.cpp" line="348"/>
         <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; kræsjet for mange ganger. Det kan ikke autoomstartes før neste innlogging.</translation>
     </message>
@@ -33,12 +33,12 @@
         <translation>Vindushåndterer å bruke.</translation>
     </message>
     <message>
-        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <location filename="../src/sessionapplication.cpp" line="89"/>
         <source>DBus Environment</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <location filename="../src/sessionapplication.cpp" line="90"/>
         <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
         <translation type="unfinished"></translation>
     </message>
@@ -58,7 +58,7 @@
     <message>
         <location filename="../src/wmselectdialog.ui" line="71"/>
         <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
-        <translation>Du kan endre dette når som helst ved å gå til Innstillinger -&gt; Sesjonsinnstillinger -&gt; Grunnleggende innstillinger.</translation>
+        <translation>Du kan endre dette når som helst ved å gå til Innstillinger -&gt; Øktinnstillinger -&gt; Grunnleggende innstillinger.</translation>
     </message>
     <message>
         <location filename="../src/wmselectdialog.cpp" line="65"/>
