@@ -53,7 +53,7 @@
     <message>
         <location filename="../src/wmselectdialog.cpp" line="65"/>
         <source>Other ...</source>
-        <translation>其它...</translation>
+        <translation>其他...</translation>
     </message>
     <message>
         <location filename="../src/wmselectdialog.cpp" line="66"/>
